@@ -38,7 +38,7 @@ static void g_cclosure_user_marshal_VOID__POINTER_INT_INT (GClosure * closure, G
 GType moserial_serial_connection_line_end_get_type (void) {
 	static GType moserial_serial_connection_line_end_type_id = 0;
 	if (G_UNLIKELY (moserial_serial_connection_line_end_type_id == 0)) {
-		static const GEnumValue values[] = {{MOSERIAL_SERIAL_CONNECTION_LINE_END_CRLF, "MOSERIAL_SERIAL_CONNECTION_LINE_END_CRLF", "crlf"}, {MOSERIAL_SERIAL_CONNECTION_LINE_END_CR, "MOSERIAL_SERIAL_CONNECTION_LINE_END_CR", "cr"}, {MOSERIAL_SERIAL_CONNECTION_LINE_END_LF, "MOSERIAL_SERIAL_CONNECTION_LINE_END_LF", "lf"}, {MOSERIAL_SERIAL_CONNECTION_LINE_END_TAB, "MOSERIAL_SERIAL_CONNECTION_LINE_END_TAB", "tab"}, {MOSERIAL_SERIAL_CONNECTION_LINE_END_NONE, "MOSERIAL_SERIAL_CONNECTION_LINE_END_NONE", "none"}, {0, NULL, NULL}};
+		static const GEnumValue values[] = {{MOSERIAL_SERIAL_CONNECTION_LINE_END_CRLF, "MOSERIAL_SERIAL_CONNECTION_LINE_END_CRLF", "crlf"}, {MOSERIAL_SERIAL_CONNECTION_LINE_END_CR, "MOSERIAL_SERIAL_CONNECTION_LINE_END_CR", "cr"}, {MOSERIAL_SERIAL_CONNECTION_LINE_END_LF, "MOSERIAL_SERIAL_CONNECTION_LINE_END_LF", "lf"}, {MOSERIAL_SERIAL_CONNECTION_LINE_END_TAB, "MOSERIAL_SERIAL_CONNECTION_LINE_END_TAB", "tab"}, {MOSERIAL_SERIAL_CONNECTION_LINE_END_ESC, "MOSERIAL_SERIAL_CONNECTION_LINE_END_ESC", "esc"}, {MOSERIAL_SERIAL_CONNECTION_LINE_END_NONE, "MOSERIAL_SERIAL_CONNECTION_LINE_END_NONE", "none"}, {0, NULL, NULL}};
 		moserial_serial_connection_line_end_type_id = g_enum_register_static ("moserialSerialConnectionLineEnd", values);
 	}
 	return moserial_serial_connection_line_end_type_id;
@@ -167,12 +167,21 @@ char* moserial_serial_connection_getLineEnd (moserialSerialConnection* self, gin
 				break;
 			}
 		}
-		default:
+		case MOSERIAL_SERIAL_CONNECTION_LINE_END_ESC:
 		{
 			{
 				char* _tmp4;
 				_tmp4 = NULL;
-				s = (_tmp4 = g_strdup (""), s = (g_free (s), NULL), _tmp4);
+				s = (_tmp4 = g_strdup ("\x1b"), s = (g_free (s), NULL), _tmp4);
+				break;
+			}
+		}
+		default:
+		{
+			{
+				char* _tmp5;
+				_tmp5 = NULL;
+				s = (_tmp5 = g_strdup (""), s = (g_free (s), NULL), _tmp5);
 				break;
 			}
 		}
@@ -208,7 +217,7 @@ void moserial_serial_connection_doDisconnect (moserialSerialConnection* self) {
 			e = inner_error;
 			inner_error = NULL;
 			{
-				g_warning ("SerialConnection.vala:112: %s", e->message);
+				g_warning ("SerialConnection.vala:116: %s", e->message);
 				(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
 			}
 		}
